OC.L10N.register(
    "mail",
    {
    "Mail" : "Αλληλογραφία",
    "Auto detect failed. Please use manual mode." : "Η αυτόματη ανίχνευση απέτυχε. Παρακαλούμε χρησιμοποιήστε τη χειροκίνητη λειτουργία.",
    "Updating account failed: " : "Αποτυχία ενημέρωσης λογαριασμού:",
    "Creating account failed: " : "Αποτυχία δημιουργίας λογαριασμού:",
    "Auto" : "Αυτόματα",
    "Name" : "Όνομα",
    "Mail Address" : "Διεύθυνση αλληλογραφίας",
    "Password" : "Συνθηματικό",
    "Manual" : "Χειροκίνητα",
    "IMAP Settings" : "Ρυθμίσεις IMAP ",
    "IMAP Host" : "Υπολογιστής IMAP",
    "IMAP Security" : "Ασφάλεια IMAP",
    "None" : "Κανένα",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Πόρτα IMAP",
    "IMAP User" : "Χρήστης IMAP",
    "IMAP Password" : "Συνθηματικό IMAP",
    "SMTP Settings" : "Ρυθμίσεις SMTP ",
    "SMTP Host" : "Υπολογιστής SMTP",
    "SMTP Security" : "Ασφάλεια SMTP ",
    "SMTP Port" : "Πόρτα SMTP",
    "SMTP User" : "Χρήστης SMTP",
    "SMTP Password" : "Συνθηματικό SMTP",
    "Save" : "Αποθήκευση",
    "Connect" : "Σύνδεση",
    "Add mail account" : "Προσθήκη λογαριασμού αλληλογραφίας",
    "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
    "From" : "Από:",
    "Select account" : "Επιλογή λογαριασμού",
    "To" : "Προς",
    "Contact or email address …" : "Επαφή ή διεύθυνση ηλ.ταχυδρομίου ...",
    "+ Copy" : "+ Αντιγραφή",
    "Copy" : "Αντιγραφή",
    "No contacts found." : "Δεν βρέθηκαν επαφές",
    "Subject" : "Θέμα",
    "Subject …" : "Θέμα...",
    "Write message …" : "Εγγραφή μηνύματος ...",
    "Saving draft …" : "Αποθήκευση προχείρου ...",
    "Draft saved" : "Το πρόχειρο αποθηκεύτηκε",
    "Upload attachment" : "Μεταφόρτωση συνημμένων",
    "Add attachment from Files" : "Προσθήκη συνημμένου από Αρχεία",
    "Uploading attachments …" : "Ανέβασμα συνημμένων ...",
    "Sending …" : "Αποστέλλεται...",
    "Error sending your message" : "Σφάλμα κατά την αποστολή του μηνύματός σας",
    "Go back" : "Πίσω",
    "Retry" : "Δοκιμή ξανά",
    "Message sent!" : "Μήνυμα εστάλη!",
    "Reply sent!" : "Η απάντηση στάλθηκε!",
    "Write another message" : "Γράψτε ένα άλλο μήνυμα",
    "Send" : "Αποστολή",
    "Uploading {percent}% …" : "Μεταφόρτωση {percent}% …",
    "Choose a file to add as attachment" : "Επιλέξτε ένα αρχείο για να προσθέσετε ως συνημμένο",
    "Plain text" : "Απλό κείμενο",
    "Rich text" : "Εμπλουτισμένο κείμενο",
    "Draft: " : "Πρόχειρο:",
    "Mark read" : "Σημείωση ως ανεγνωσμένου",
    "Mark unread" : "σημειώστε ως μη αναγνωσμένο",
    "Delete" : "Διαγραφή",
    "Report this bug" : "Αναφέρετε αυτό το σφάλμα",
    "Loading messages" : "Φόρτωση μηνυμάτων",
    "Not found" : "Δε βρέθηκε",
    "Reply" : "Απάντηση",
    "Reply to sender only" : "Απάντηση μόνο στον αποστολέα",
    "Forward" : "Προώθηση",
    "Import into calendar" : "Εισαγωγή στο ημερολόγιο",
    "Download attachment" : "Λήψη συνημμένου",
    "Save to Files" : "Αποθήκευση στα Αρχεία",
    "Choose a folder to store the attachment in" : "Επιλέξτε ένα φάκελο για να αποθηκεύσετε τα συνημμένα",
    "Save all to Files" : "Αποθήκευση όλων στα Αρχεία",
    "Choose a folder to store the attachments in" : "Επιλέξτε ένα φάκελο για να αποθηκεύσετε μέσα τα συνημμένα",
    "The images have been blocked to protect your privacy." : "Οι εικόνες έχουν αποκλειστεί για να προστατευθεί η ιδιωτικότητά σας.",
    "New message" : "Νέο μήνυμα",
    "Settings" : "Ρυθμίσεις",
    "Edit account" : "Επεξεργασία λογαριασμού",
    "Delete account" : "Διαγραφή λογαριασμού",
    "Add folder" : "Προσθήκη φακέλου",
    "Show all folders" : "Εμφάνιση όλων των φακέλων",
    "Collapse folders" : "Σύμπτυξη φακέλων",
    "Mark all messages of this folder as read" : "Σημείωση όλων των μυνημάτων ως αναγνωσμένων",
    "Add subfolder" : "Προσθήκη υποφακέλου",
    "{total} messages" : "{total} μυνήματα",
    "Loading …" : "Φόρτωση…",
    "Signature" : "Υπογραφή",
    "Signature …" : "Υπογραφή...",
    "Save signature" : "Αποθήκευση υπογραφής",
    "Mail app" : "Εφαρμογή αλληλογραφίας",
    "General" : "Γενικά",
    "Email address" : "Διεύθυνση αλληλογραφίας",
    "IMAP" : "IMAP",
    "User" : "Χρήστης",
    "Host" : "Διακομιστής",
    "Port" : "Θύρα",
    "SMTP" : "SMTP",
    "Account settings" : "Ρυθμίσεις λογαριασμού",
    "Change name" : "Αλλαγή ονόματος",
    "Mail server" : "Διακομιστής αλληλογραφίας",
    "Speed up your Mail experience with these quick shortcuts." : "Βελτιώστε την ταχύτητά σας στην εμπειρία χρήσης στο πρόγραμμα Αλληλογραφίας με αυτές τις συντομεύσεις.",
    "Compose new message" : "Σύνταξη νέου μηνύματος",
    "Newer message" : "Νεότερο μήνυμα",
    "Older message" : "Παλαιότερο μήνυμα",
    "Toggle star" : "Εναλλαγή αστεριού",
    "Toggle unread" : "Εναλλαγή αδιάβαστων",
    "Search" : "Αναζήτηση",
    "Refresh" : "Ανανέωση",
    "Connect your mail account" : "Συνδέστε το λογαριασμό αλληλογραφίας σας",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "Αλληλογραφία Nextcloud",
    "Could not load {tag}{name}{endtag}" : "Αδυναμία φόρτωσης {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Παρουσιάστηκε πρόβλημα φόρτωσης {tag}{name}{endtag}",
    "Error loading message" : "Σφάλμα φόρτωσης μηνύματος",
    "Forwarding to %s" : "Προώθηση σε %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Κάντε κλικ εδώ εάν δεν ανακατευθυνθείτε αυτόματα μέσα σε λίγα δευτερόλεπτα.",
    "Redirect" : "Ανακατεύθυνση",
    "The link leads to %s" : "Αυτός ο σύνδεσμος οδηγεί στο %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Εάν δεν θέλετε να επισκεφθείτε την σελίδα, μπορείτε να επιστρέψετε στην <a href=\"%s\">Αλληλογραφία</a>.",
    "Continue to %s" : "Συνέχεια στο %s"
},
"nplurals=2; plural=(n != 1);");
